Generator class abstract

Base contract for all project generators within the CLI.

Implementers

Constructors

Generator()
Const constructor for subclasses.
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

generate(List<IModuleCodeContributor> modules, Logger logger, Map<String, dynamic> coreVars, String generateTo) → Future<void>
Generates files based on provided modules and context.
mapMergeStrategy(FileMergeStrategy strategy) → FileConflictResolution
Maps a high-level FileMergeStrategy to a mason FileConflictResolution.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited