devDependencies property

List<String> devDependencies
final

The packages that the tests use besides those of the app, which the matrix adds to the app as dev dependencies, such as the mocks of the platform side of a plugin.

Implementation

final List<String> devDependencies;