directory property

String directory
final

The directory of the files that go into an app, each at its path relative to the directory, such as test/firebase_core_test.dart, over the file of the app at that path, if the app has one.

In the text of each file, {{app_name}} becomes the name of the package of the app, and {{<key>}} the value of each key of the values of the app. Hidden files stay out. The files of the tests of an app may use those of other tests that the app always has too, such as the tests of a module that another depends on.

Implementation

final String directory;