MatrixAppTestException class final

A problem of the files of MatrixAppTests, which addAppTests finds before it copies them into an app.

Implemented types

Constructors

MatrixAppTestException(String message)
Creates the exception with message.
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
message → String
What is wrong with the files.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited