MatrixCommands class final

The commands that runMatrix runs for each app, which tests of the matrix may replace; each left null is the real one.

Constructors

MatrixCommands({MatrixCreate? create, MatrixAnalyze? analyze, MatrixTest? test})
Creates the commands, with the real one for each left null.
const

Properties

analyze → MatrixAnalyze?
Analyzes an app: by default flutter analyze.
final
create → MatrixCreate?
Generates an app: by default smf create of this CLI with the modules of the matrix.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
test → MatrixTest?
Adds the tests that apply to an app and runs them: by default runAppTests.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited