MatrixFlutter typedef
Runs flutter with arguments in directory and returns the exit code
and the output.
Implementation
typedef MatrixFlutter = Future<(int, String)> Function(
List<String> arguments,
String directory,
);
Runs flutter with arguments in directory and returns the exit code
and the output.
typedef MatrixFlutter = Future<(int, String)> Function(
List<String> arguments,
String directory,
);