MatrixTest typedef

MatrixTest = Future<(int, String)> Function(GeneratedApp generated, MatrixApp app, List<MatrixAppTest> tests)

Adds tests to generated, the app of the matrix app, and runs them with flutter test; returns the exit code of the first command that fails and the output up to it, or 0 and the output of all.

Implementation

typedef MatrixTest = Future<(int, String)> Function(
  GeneratedApp generated,
  MatrixApp app,
  List<MatrixAppTest> tests,
);