SafeGenerationRunner class

Runs project generation into a temporary workspace and moves the result to the final destination upon success. Always cleans up the temp directory.

Constructors

SafeGenerationRunner()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
run(CliContext context, {String onConflict = 'prompt'}) → Future<void>
Performs safe generation using the CLI engine and the provided context.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited