createArguments method
The arguments of smf create that generate the app as appName in
directory, as CI does: without questions, external setup or the
full dart fix, and failing instead of leaving out a module.
Implementation
List<String> createArguments(String appName, String directory) => [
'create',
appName,
'-m',
modules.join(','),
for (final MapEntry(:key, :value) in roleOptions.entries)
if (value != null) '--$key=$value',
'-o',
directory,
'--on-conflict',
'replace',
'--no-input',
'--skip-external-setup',
'--no-dart-fix',
'--strict',
];